@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2017 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -51,6 +51,24 @@ typedef enum {
 } GMimeContentEncoding;
 
 
+/**
+ * GMimeEncodingConstraint:
+ * @GMIME_ENCODING_CONSTRAINT_7BIT: The stream data must fit within the 7bit ASCII range.
+ * @GMIME_ENCODING_CONSTRAINT_8BIT: The stream data may have bytes with the high bit set, but no null bytes.
+ * @GMIME_ENCODING_CONSTRAINT_BINARY: The stream may contain any binary data.
+ *
+ * Used with functions like g_mime_filter_best_encoding() and
+ * g_mime_object_encode() as the 'constraint' argument. These values
+ * provide a means of letting the filter know what the encoding
+ * constraints are for the stream.
+ **/
+typedef enum {
+	GMIME_ENCODING_CONSTRAINT_7BIT,
+	GMIME_ENCODING_CONSTRAINT_8BIT,
+	GMIME_ENCODING_CONSTRAINT_BINARY
+} GMimeEncodingConstraint;
+
+
 GMimeContentEncoding g_mime_content_encoding_from_string (const char *str);
 const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
 
@@ -97,7 +115,7 @@ const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
 /**
  * GMIME_UUDECODE_STATE_INIT:
  *
- * Initial state for the g_mime_utils_uudecode_step() function.
+ * Initial state for the g_mime_encoding_uudecode_step() function.
  **/
 #define GMIME_UUDECODE_STATE_INIT   (0)
 
@@ -105,7 +123,7 @@ const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
 /**
  * GMIME_UUDECODE_STATE_BEGIN:
  *
- * State for the g_mime_utils_uudecode_step() function, denoting that
+ * State for the g_mime_encoding_uudecode_step() function, denoting that
  * the 'begin' line has been found.
  **/
 #define GMIME_UUDECODE_STATE_BEGIN  (1 << 16)
@@ -114,12 +132,13 @@ const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
 /**
  * GMIME_UUDECODE_STATE_END:
  *
- * State for the g_mime_utils_uudecode_step() function, denoting that
+ * State for the g_mime_encoding_uudecode_step() function, denoting that
  * the end of the UU encoded block has been found.
  **/
 #define GMIME_UUDECODE_STATE_END    (1 << 17)
 #define GMIME_UUDECODE_STATE_MASK   (GMIME_UUDECODE_STATE_BEGIN | GMIME_UUDECODE_STATE_END)
 
+typedef struct _GMimeEncoding GMimeEncoding;
 
 /**
  * GMimeEncoding:
@@ -131,13 +150,13 @@ const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
  *
  * A context used for encoding or decoding data.
  **/
-typedef struct _GMimeEncoding {
+struct _GMimeEncoding {
 	GMimeContentEncoding encoding;
 	unsigned char uubuf[60];
 	gboolean encode;
 	guint32 save;
 	int state;
-} GMimeEncoding;
+};
 
 
 void g_mime_encoding_init_encode (GMimeEncoding *state, GMimeContentEncoding encoding);
